@@ -1,5 +1,7 @@
 mod array;
 mod bool;
+#[cfg(feature = "bson")]
+mod bson;
 mod btreemap;
 mod btreeset;
 #[cfg(feature = "chrono")]
